==> oddmuse-1.310.tar.gz: oddmuse-1.310/japanese-utf8.pl <==
# UTF-8 encoded Japanese translation file for use with Oddmuse
#
# Copyright (c) 2003  ...
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
# This file should be saved into the same folder where the config file
# resides.  Load it from the config file:
#
# do 'japanese-utf8.pl;
#
# This translation was last checked for Oddmuse version 1.215.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

XML::RSS is not available on this system.

LWP::UserAgent is not available on this system.

diff

history

 . . . . 

Click to create this page

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Invalid action parameter %s

Invalid URL.

Page name is too long: %s

Invalid Page %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Page name may not contain space characters: %s

Preview:

Preview only, not yet saved

Please go on to %s.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Could not open old %s log file

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List only major changes

Include minor changes

List all changes

%s days

List later changes

Username:

Host:

Language:

Filters

Go!

(minor)

rollback

from %s

History of %s

Compare

Revision %s

by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

new comment

Save

Preview

Comments on this page

Edit revision %s of this page

Edit text of this page

This page is read-only

View other revisions

View current revision

View all changes

Back to %s

Last edited

Edited

by %s

(diff)

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Search:

Replace:

Validate HTML

Validate CSS

Difference (from revision %1 to %2)

revision %s

current revision

Difference (from prior %s revision)

major

minor

No diff available.

Changed:

Removed:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save an nameless page.

Cannot open %s

Cannot write %s

Could not get %s lock

Unlocking

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Editing Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Password

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

Index of all pages

all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Full Link List

Complete Content

The main page is %s.

Editing not allowed for %s.

SampleUndefinedPage

%s cannot be defined.

Sample_Undefined_Page

[[%s]] cannot be defined.

Only an administrator can create %s

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Could not get a lock to merge!

you

ancestor

other

Ping

No response.

Maintenance on all pages

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Inter links:

Near links:

Too many connections by %s

Recent Visitors

Referrers

All Referrers

anchor first defined here: %s

Click to search for references to this permanent anchor

END_OF_TRANSLATION

==> oddmuse-1.437.tar.gz: oddmuse-1.437/japanese-utf8.pl <==
# UTF-8 encoded Japanese translation file for use with Oddmuse
#
# Copyright (c) 2003  ...
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.215.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to create this page

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Invalid action parameter %s

Invalid URL.

Page name is missing

Page name is too long: %s

Invalid Page %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Page name may not contain space characters: %s

Preview:

Preview only, not yet saved

Please go on to %s.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Could not open old %s log file

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

List only major changes

Include minor changes

%s days

List later changes

Username:

Host:

Language:

Filters

Go!

(minor)

rollback

new

from %s

History of %s

Compare

Revision %s

by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Last edited

Edited

by %s

(diff)

Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page

Edit revision %s of this page

Edit text of this page

e

This page is read-only

View other revisions

View current revision

View all changes

Back to %s

new comment

s

Save

Preview

Search:

Replace:

Validate HTML

Validate CSS

Difference (from revision %1 to %2)

revision %s

current revision

Difference (from prior %s revision)

major

minor

No diff available.

Changed:

Removed:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save an nameless page.

Cannot open %s

Cannot write %s

Could not get %s lock

Unlocking

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Editing Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Password

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

Index of all pages

all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Editing not allowed for %s.

SampleUndefinedPage

%s cannot be defined.

Sample_Undefined_Page

[[%s]] cannot be defined.

Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Could not get a lock to merge!

you

ancestor

other

Maintenance on all pages

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Inter links:

Near links:

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Recent Visitors

Referrers

All Referrers

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Calendar %s

Footnotes:

image: %s

Languages:

Show!

Define

Full Link List

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Portrait

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Blog

END_OF_TRANSLATION
